@@ -121,6 +121,7 @@ class QRydSimulator(Backend):
             seed_simulator=None,
             parameter_binds=None,
             develop=False,
+            fusion_max_qubits=4,
         )
 
     def set_option(self, key, value):
@@ -143,6 +144,9 @@ class QRydSimulator(Backend):
 
         options = {
             "develop": kwargs.get("develop", self.options.develop),
+            "fusion_max_qubits": kwargs.get(
+                "fusion_max_qubits", self.options.fusion_max_qubits
+            ),
             "shots": kwargs.get("shots", self.options.shots),
             "memory": kwargs.get("memory", self.options.memory),
             "seed_simulator": kwargs.get("seed_simulator", self.options.seed_simulator),
@@ -172,10 +176,10 @@ class QRydSimulator(Backend):
             )
 
         job_dict = self._convert_to_wire_format(circuit, options)
-        job_handle = self._submit(job_dict, self._provider.token)
+        job_handle = self._submit(job_dict, self._provider.session)
         job_url = job_handle.headers["Location"]
 
-        return QRydSimulatorJob(self, job_url, self._provider.token, options, circuit)
+        return QRydSimulatorJob(self, job_url, self._provider.session, options, circuit)
 
     def _convert_to_wire_format(self, circuit, options):
         circuit_dict = {
@@ -402,16 +406,15 @@ class QRydSimulator(Backend):
         job_dict = {
             "backend": self.configuration().backend_name,
             "develop": options["develop"],
+            "fusion_max_qubits": options["fusion_max_qubits"],
             "seed": options["seed_simulator"],
             "pcz_theta": float(PCZGate().get_pcz_theta()),
             "program": circuit_dict,
         }
         return job_dict
 
-    def _submit(self, job_dict, token):
-        response = requests.post(
-            self.url_base, headers={"X-API-Key": token}, json=job_dict
-        )
+    def _submit(self, job_dict, session):
+        response = session.post(self.url_base, json=job_dict)
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as error:
